diff --git a/Drupal.class.php b/Drupal.class.php
index b81ed5e..23af297 100644
--- a/Drupal.class.php
+++ b/Drupal.class.php
@@ -5,37 +5,21 @@
  */
 
 /**
  * Root directory of Drupal installation.
  */
-define('DRUPAL_ROOT', getcwd());
-
-require_once DRUPAL_ROOT . '/includes/bootstrap.inc';
+define('DRUSH_ROOT', '/home/owen/workspace/drush');
+require(DRUSH_ROOT . '/includes/bootstrap.inc');
+drush_bootstrap_prepare();
 
 class Drupal {
-
     public function __construct() {
-      $_SERVER['REMOTE_ADDR'] = '127.0.0.1';
-      $_SERVER['SERVER_SOFTWARE'] = 'appserver-in-php';
-      $_SERVER['PHP_SELF'] = basename(__FILE__);
-      drupal_bootstrap(DRUPAL_BOOTSTRAP_FULL);
+      _drush_bootstrap_global_options();
+      drush_bootstrap(DRUSH_BOOTSTRAP_DRUPAL_FULL);
+      $GLOBALS['base_url'] = 'http://127.0.0.1:8082';
     }
 
     public function __invoke($context) {
-      // Support clean URLs
-      $GLOBALS['conf']['clean_url'] = 1;
       $GLOBALS['_GET']['q'] = substr($context['env']['REQUEST_URI'], 1);
-
-      //$GLOBALS['user'] = drupal_anonymous_user();
-      $GLOBALS['user'] = user_load(1);
-      unset($GLOBALS['theme']);
-      drupal_static_reset();
-      drupal_language_initialize();
-      drupal_page_header();
-      drupal_path_initialize();
-      menu_set_custom_theme();
-      drupal_theme_initialize();
-      module_invoke_all('init');
-
       ob_start();
       menu_execute_active_handler($_GET['q']);
       $body = ob_get_clean();
@@ -51,8 +35,6 @@ class Drupal {
           $headers[] = $value;
         }
       }
-
-      return array($status, $headers, $body);
+      return array(200, $headers, $body);
     }
-
 }
@@ -5,37 +5,21 @@
 
 /**
- * Root directory of Drupal installation.
+ * Root directory of Drush installation.
  */
